Welcome
^^^^^^^^

``ngs_toolkit`` is a Python library for the analysis of NGS data.

Its goals are to provide a highly customizable set of objects and tools that interact with each other to create data processing and analysis workflows in both a interactive and scripted way.

``ngs-toolkit`` is unique in the following aspects:

 - Includes tried-and-tested (and published) workflows for end-to-end analysis of NGS data, while at the same time allowing high customization;
 - Tailored for well-established NGS data types, but supporting arbitrary data types;
 - Its target audience are mid-level bioinfomaticians which want to "get it done" and focus on interpretation of results while at the same time allowing running workflows with minimal programming experience.

``ngs-toolkit`` is reaching maturity, with a stable API (from version 0.14 on), improving documentation and increasing test coverage.

Head to the :doc:`Introduction <intro>` to see installation instructions and quick use, or have a look at the catalogue of available functions in the :doc:`API <api>`.

Contents
^^^^^^^^

.. toctree::
    :maxdepth: 1

    intro
    examples
    concepts
    log_config
    report
    manager_programs
    recipes
    api
    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Links
^^^^^^^^

 * Documentation: http://toolkit.readthedocs.io/
 * Issues and source code: https://github.com/afrendeiro/toolkit
